@@ -12,7 +12,7 @@ import unittest
 
 from pyglet import font
 
-import base_text
+from . import base_text
 
 class TEST_HALIGN(base_text.TextTestBase):
     font_name = ''
